==> clean900_2.0.1-8.tar.gz: clean900-2.0.1/usr/bin/clean900/ripbackup-en.sh <==
#!/bin/sh
#Ripbackup.sh
#version 2.0.0
#by incrys for www.maemomeego.net

if [ `id -u` != 0 ] ; then
    exec root <<EOF
exec sh $0 $*
EOF
	exit $?
fi 

conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`

if [ "$conn" != "0" ]
	then
		ric=`zenity --warning --title CleaN900 --text "You must have the active connection, preferably wifi. If you want to connect click OK, otherwise press out";echo $?`
			if [ "$ric" -eq 0 ]
				then
					dbus-send --system --type=method_call --dest=com.nokia.icd_ui /com/nokia/icd_ui com.nokia.icd_ui.show_conn_dlg boolean:false
					sleep 3
					dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Connection in progress... Please wait..."
					sleep 5

					ricrip=`zenity --question --title CleaN900 --text "Are you sure you want to restore a backup file? If you want to restore choose OK, otherwise press out";echo $?`
						if [ "$ricrip" -eq 0 ]
							then
			cerca=`cd /home/user/MyDocs/backupclean900 && find |grep -c *.txt`
				if [ "$cerca" -ne "1" ]
					then
						zenity --warning --title CleaN900 --text "You must first create a backup of applications!!"
						exit
					else
						backup=`zenity --title CleaN900 --file-selection --text='Select the file' --filename=/home/user/MyDocs/backupclean900/ --file-filter "*.txt"`
						dpkg --set-selections < $backup
						dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Working... Please wait..."
						res=$(echo "n" | apt-get dselect-upgrade )
							if [ $? -eq 1 ]; then
								if zenity --title=Clean900 --question --text "$res"; then
									res=$(apt-get dselect-upgrade -f -y --force-yes)
									dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Recovery made"
									else
										dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
								fi
							fi
								zenity --title=Clean900 --info --text "$res"
				fi
							else
								dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
						fi
				else
					dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
			fi
	else
		ricrip=`zenity --question --title CleaN900 --text "Are you sure you want to restore a backup file? If you want to restore choose OK, otherwise press out";echo $?`
			if [ "$ricrip" -eq 0 ]
				then
					cerca=`cd /home/user/MyDocs/backupclean900 && find |grep -c *.txt`
						if [ "$cerca" -ne "1" ]
							then
								zenity --warning --title CleaN900 --text "You must first create a backup of applications!!"
								exit
							else
								backup=`zenity --title CleaN900 --file-selection --text='Select the file' --filename=/home/user/MyDocs/backupclean900/ --file-filter "*.txt"` && dpkg --set-selections < $backup
								dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Working... Please wait..."
								res=$(echo "n" | apt-get dselect-upgrade )
									if [ $? -eq 1 ]; then
										if zenity --title=Clean900 --question --text "$res"; then
											res=$(apt-get dselect-upgrade -f -y --force-yes)
											dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Recovery made"
											else
										dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
										fi
									fi
								zenity --title=Clean900 --info --text "$res"
						fi
				else
					dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
			fi
fi

==> clean900_2.0.1-9.9.tar.gz: clean900-2.0.1/usr/bin/clean900/ripbackup-en.sh <==
#!/bin/sh
#Ripbackup.sh
#version 2.0.1-9.8
#by incrys for www.smartphonetab.net

if [ `id -u` != 0 ] ; then
    exec root <<EOF
exec sh $0 $*
EOF
	exit $?
fi 

conn=`ping -c 1 209.236.120.65 |grep 'received' | awk -F',' '{ print $2 }' | awk '{ print $1 }'`

if [ "$conn" != "0" ]
	then
		ric=`zenity --warning --title CleaN900 --text "You must have the active connection, preferably wifi. If you want to connect click OK, otherwise press out";echo $?`
			if [ "$ric" -eq 0 ]
				then
					dbus-send --system --type=method_call --dest=com.nokia.icd_ui /com/nokia/icd_ui com.nokia.icd_ui.show_conn_dlg boolean:false
					sleep 3
					dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Connection in progress... Please wait..."
					sleep 5

					ricrip=`zenity --question --title CleaN900 --text "Are you sure you want to restore a backup file? If you want to restore choose OK, otherwise press out";echo $?`
						if [ "$ricrip" -eq 0 ]
							then
			cerca=`cd /home/user/MyDocs/backupclean900 && find |grep -c *.txt`
				if [ "$cerca" -ne "1" ]
					then
						zenity --warning --title CleaN900 --text "You must first create a backup of applications!!"
						exit
					else
						backup=`zenity --title CleaN900 --file-selection --text='Select the file' --filename=/home/user/MyDocs/backupclean900/ --file-filter "*.txt"`
						dpkg --set-selections < $backup
						dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Working... Please wait..."
						res=$(echo "n" | apt-get dselect-upgrade )
							if [ $? -eq 1 ]; then
								if zenity --title=Clean900 --question --text "$res"; then
									res=$(apt-get dselect-upgrade -f -y --force-yes)
									dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Recovery made"
									else
										dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
								fi
							fi
								zenity --title=Clean900 --info --text "$res"
				fi
							else
								dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
						fi
				else
					dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
			fi
	else
		ricrip=`zenity --question --title CleaN900 --text "Are you sure you want to restore a backup file? If you want to restore choose OK, otherwise press out";echo $?`
			if [ "$ricrip" -eq 0 ]
				then
					cerca=`cd /home/user/MyDocs/backupclean900 && find |grep -c *.txt`
						if [ "$cerca" -ne "1" ]
							then
								zenity --warning --title CleaN900 --text "You must first create a backup of applications!!"
								exit
							else
								backup=`zenity --title CleaN900 --file-selection --text='Select the file' --filename=/home/user/MyDocs/backupclean900/ --file-filter "*.txt"` && dpkg --set-selections < $backup
								dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Working... Please wait..."
								res=$(echo "n" | apt-get dselect-upgrade )
									if [ $? -eq 1 ]; then
										if zenity --title=Clean900 --question --text "$res"; then
											res=$(apt-get dselect-upgrade -f -y --force-yes)
											dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Recovery made"
											else
										dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
										fi
									fi
								zenity --title=Clean900 --info --text "$res"
						fi
				else
					dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
			fi
fi
